@@ -199,6 +199,7 @@ def cbcBayesPostProc(
                         #header file
                         header=None,
                         psd_files=None,
+                        greedy=True ## If true will use greedy bin for 1-d credible regions. Otherwise use 2-steps KDE
                     ):
     """
     This is a demonstration script for using the functionality/data structures
@@ -595,13 +596,17 @@ def cbcBayesPostProc(
     tabid='onedconftable'
     html_ogci=html.add_collapse_section('1D confidence intervals (greedy binning)',legend=legend,innertable_id=tabid)
     html_ogci_write='<table id="%s" border="1"><tr><th/>'%tabid
-    
+    clasciiout="#parameter \t"
     confidence_levels.sort()
     for cl in confidence_levels:
         html_ogci_write+='<th>%f</th>'%cl
+        clasciiout+="%s\t"%('%.02f'%cl)
     if injection:
         html_ogci_write+='<th>Injection Confidence Level</th>'
         html_ogci_write+='<th>Injection Confidence Interval</th>'
+        clasciiout+="Injection_Confidence_Level\t"
+        clasciiout+="Injection_Confidence_Interval"
+    clasciiout+='\n'
     html_ogci_write+='</tr>'
 
     onepdfdir=os.path.join(outdir,'1Dpdf')
@@ -624,7 +629,8 @@ def cbcBayesPostProc(
         cycles = sort(pos['cycle'].samples)
         Ncycles = cycles[-1]-cycles[0]
         Nskip = cycles[1]-cycles[0]
-
+    
+    printed=0
     for par_name in oneDMenu:
         par_name=par_name.lower()
         try:
@@ -640,31 +646,52 @@ def cbcBayesPostProc(
 
         #print "Binning %s to determine confidence levels ..."%par_name
         binParams={par_name:par_bin}
-
-        toppoints,injectionconfidence,reses,injection_area,cl_intervals=bppu.greedy_bin_one_param(pos,binParams,confidence_levels)
-
+        injection_area=None
+        injection_area=None
+        if greedy:
+          if printed==0:
+            print "Using greedy 1-d binning credible regions\n"
+            printed=1
+          toppoints,injectionconfidence,reses,injection_area,cl_intervals=bppu.greedy_bin_one_param(pos,binParams,confidence_levels)
+        else:
+          if printed==0:
+            print "Using 2-step KDE 1-d credible regions\n"
+            printed=1
+          if pos[par_name].injval is None:
+            injCoords=None
+          else:
+            injCoords=[pos[par_name].injval]
+          _,reses,injstats=bppu.kdtree_bin2Step(pos,[par_name],confidence_levels,injCoords=injCoords)
+          if injstats is not None:
+            injectionconfidence=injstats[3]
+            injection_area=injstats[4]
+             
         #oneDContCL,oneDContInj = bppu.contigious_interval_one_param(pos,binParams,confidence_levels)
 
         #Generate new BCI html table row
         BCItableline='<tr><td>%s</td>'%(par_name)
+        clasciiout+="%s\t"%par_name
         cls=reses.keys()
         cls.sort()
 
         for cl in cls:
             BCItableline+='<td>%f</td>'%reses[cl]
-
+            clasciiout+="%f\t"%reses[cl]
         if injection is not None:
             if injectionconfidence is not None and injection_area is not None:
 
                 BCItableline+='<td>%f</td>'%injectionconfidence
                 BCItableline+='<td>%f</td>'%injection_area
+                clasciiout+="%f\t"%injectionconfidence
+                clasciiout+="%f"%injection_area
 
             else:
                 BCItableline+='<td/>'
                 BCItableline+='<td/>'
-
+                clasciiout+="nan\t"
+                clasciiout+="nan"
         BCItableline+='</tr>'
-
+        clasciiout+="\n"
         #Append new table line to section html
         html_ogci_write+=BCItableline
 
@@ -835,6 +862,10 @@ def cbcBayesPostProc(
     if html_corner!='':
       html_co=html.add_collapse_section('Corner plots',legend=legend,innertable_id=tabid)
       html_co.write(html_corner)
+    if clasciiout:
+      fout=open(os.path.join(outdir,'confidence_levels.txt'),'w')
+      fout.write(clasciiout)
+      fout.close()
     #==================================================================#
     #2D posteriors
     #==================================================================#
@@ -1195,6 +1226,7 @@ if __name__=='__main__':
     parser.add_option("--email",action="store",default=None,type="string",metavar="user@ligo.org",help="Send an e-mail to the given address with a link to the finished page.")
     parser.add_option("--archive",action="store",default=None,type="string",metavar="results.tar.gz",help="Create the given tarball with all results")
     parser.add_option("--psdfiles",action="store",default=None,type="string",metavar="H1,L1,V1",help="comma separater list of ASCII files with PSDs, one per IFO")
+    parser.add_option("--kdecredibleregions",action="store_true",default=False,help="If given, will use 2-step KDE trees to estimate 1-d credible regions [default false: use greedy binning]")
     (opts,args)=parser.parse_args()
 
     datafiles=[]
@@ -1340,7 +1372,8 @@ if __name__=='__main__':
                         #header file for parameter names in posterior samples
                         header=opts.header,
                         # ascii files (one per IFO) containing  freq - PSD columns
-                        psd_files=opts.psdfiles 
+                        psd_files=opts.psdfiles,
+                        greedy=not(opts.kdecredibleregions)
                     )
 
     if opts.archive is not None:
