@@ -1,7 +1,7 @@
-id = "127f772a85ce01e58e3559db1487119cf4c26ec8"
-date = "2014-11-19 20:10:17 +0000"
-branch = "pylal-0.6.x"
-tag = "pylal-v0.6.0-v1"
+id = "54990ee22a0e95937ec218f008f20ba3b9fdbda8"
+date = "2015-06-01 17:09:52 +0000"
+branch = "master"
+tag = "pylal-0.7.2-v1"
 if tag == "None":
     tag = None
 author = "Kipp Cannon <kipp.cannon@ligo.org>"
@@ -9,12 +9,12 @@ builder = "Kipp Cannon <kipp.cannon@ligo.org>"
 committer = "Kipp Cannon <kipp.cannon@ligo.org>"
 status = "CLEAN: All modifications committed"
 version = id
-verbose_msg = """Branch: pylal-0.6.x
-Tag: pylal-v0.6.0-v1
-Id: 127f772a85ce01e58e3559db1487119cf4c26ec8
+verbose_msg = """Branch: master
+Tag: pylal-0.7.2-v1
+Id: 54990ee22a0e95937ec218f008f20ba3b9fdbda8
 
 Builder: Kipp Cannon <kipp.cannon@ligo.org>
-Build date: 2014-11-19 20:18:30 +0000
+Build date: 2015-06-01 17:10:24 +0000
 Repository status: CLEAN: All modifications committed"""
 
 import warnings
@@ -33,9 +33,9 @@ def check_match(foreign_id, onmismatch="raise"):
     """
     if onmismatch not in ("raise", "warn"):
         raise ValueError, onmismatch + " is an unrecognized value of onmismatch"
-    if foreign_id == "127f772a85ce01e58e3559db1487119cf4c26ec8":
+    if foreign_id == "54990ee22a0e95937ec218f008f20ba3b9fdbda8":
         return
-    msg = "Program id (127f772a85ce01e58e3559db1487119cf4c26ec8) does not match given id (%s)." % foreign_id
+    msg = "Program id (54990ee22a0e95937ec218f008f20ba3b9fdbda8) does not match given id (%s)." % foreign_id
     if onmismatch == "raise":
         raise VersionMismatchError, msg
 
