@@ -1,4 +1,4 @@
-# Copyright (C) 2006--2013  Kipp Cannon
+# Copyright (C) 2006--2014  Kipp Cannon
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -25,15 +25,9 @@
 
 
 import itertools
-import sys
-import warnings
 
 
-from glue import iterutils
 from glue import offsetvector
-from glue.ligolw import lsctables
-from glue.ligolw import utils as ligolw_utils
-from glue.ligolw.utils import time_slide as ligolw_time_slide
 from pylal import git_version
 
 
@@ -42,21 +36,6 @@ __version__ = "git id %s" % git_version.id
 __date__ = git_version.date
 
 
-def get_time_slide_id(*args, **kwargs):
-	warnings.warn("pylal.ligolw_tisi.get_time_slide_id() is deprecated.  use glue.ligolw.utils.time_slide.get_time_slide_id() instead.", DeprecationWarning)
-	return ligolw_time_slide.get_time_slide_id(*args, **kwargs)
-
-
-def time_slides_vacuum(*args, **kwargs):
-	warnings.warn("pylal.ligolw_tisi.time_slides_vacuum() is deprecated.  use glue.ligolw.utils.time_slide.time_slides_vacuum() instead.", DeprecationWarning)
-	return ligolw_time_slide.time_slides_vacuum(*args, **kwargs)
-
-
-def time_slide_list_merge(*args, **kwargs):
-	warnings.warn("pylal.ligolw_tisi.time_slide_list_merge() is deprecated.  use glue.ligolw.utils.time_slide.time_slide_list_merge() instead.", DeprecationWarning)
-	return ligolw_time_slide.time_slide_list_merge(*args, **kwargs)
-
-
 #
 # =============================================================================
 #
@@ -80,33 +59,33 @@ def parse_slidespec(slidespec):
 	Example:
 
 	>>> parse_slidespec("H1=-5:+5:0.5")
-	('H1', [-5.0, -4.5, -4.0, -3.5, -3.0, -2.5, -2.0, -1.5, -1.0, -0.5,
-	0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0])
+	('H1', [-5.0, -4.5, -4.0, -3.5, -3.0, -2.5, -2.0, -1.5, -1.0, -0.5, 0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0])
+	>>> parse_slidespec("H1=+5:-5:-0.5")
+	('H1', [-5.0, -4.5, -4.0, -3.5, -3.0, -2.5, -2.0, -1.5, -1.0, -0.5, 0.0, 0.5, 1.0, 1.5, 2.0, 2.5, 3.0, 3.5, 4.0, 4.5, 5.0])
+	>>> parse_slidespec("H1=-5:+5:8")
+	('H1', [-5.0, 3.0])
 	"""
 	try:
 		instrument, rangespec = slidespec.split("=")
 	except ValueError:
 		raise ValueError("cannot parse time slide '%s'" % slidespec)
 	offsets = set()
-	for range in [s.strip() for s in rangespec.split(",")]:
+	for rng in [s.strip() for s in rangespec.split(",")]:
 		try:
-			first, last, step = map(float, range.split(":"))
+			first, last, step = map(float, rng.split(":"))
 		except ValueError:
-			raise ValueError("malformed range '%s' in '%s'" % (range, rangespec))
+			raise ValueError("malformed range '%s' in '%s'" % (rng, rangespec))
 		if step == 0:
 			if first != last:
-				raise ValueError("divide by zero in range '%s'" % range)
+				raise ValueError("divide by zero in range '%s'" % rng)
 			offsets.add(first)
 			continue
-		if (last - first) / step < 0.0:
-			raise ValueError("step has wrong sign in range '%s'" % range)
+		elif last > first if step < 0 else last < first:
+			raise ValueError("step has wrong sign in range '%s'" % rng)
 
 		for i in itertools.count():
 			x = first + i * step
-			if step > 0:
-				if not (first <= x <= last):
-					break
-			elif not (last <= x <= first):
+			if not min(first, last) <= x <= max(first, last):
 				break
 			offsets.add(x)
 	return instrument.strip(), sorted(offsets)
@@ -145,54 +124,13 @@ def parse_inspiral_num_slides_slidespec(slidespec):
 	Example:
 
 	>>> parse_inspiral_num_slides_slidespec("3:H1=0,H2=5,L1=10")
-	(3, {'H2': 5.0, 'H1': 0.0, 'L1': 10.0})
+	(3, offsetvector({'H2': 5.0, 'H1': 0.0, 'L1': 10.0}))
 	"""
 	count, offsets = slidespec.strip().split(":")
 	offsetvect = offsetvector.offsetvector((instrument.strip(), float(offset)) for instrument, offset in (token.strip().split("=") for token in offsets.strip().split(",")))
 	return int(count), offsetvect
 
 
-#
-# =============================================================================
-#
-#                                     I/O
-#
-# =============================================================================
-#
-
-
-@lsctables.use_in
-class DefaultContentHandler(lsctables.ligolw.LIGOLWContentHandler):
-	pass
-
-
-def load_time_slides(filename, verbose = False, gz = None, contenthandler = DefaultContentHandler):
-	"""
-	Load a time_slide table from the LIGO Light Weight XML file named
-	filename, or stdin if filename is None.  See
-	glue.ligolw.utils.load_filename() for a description of the verbose
-	and gz parameters.  The return value is a dictionary mapping each
-	time slide ID to a dictionary of instrument/offset pairs for that
-	time slide.
-
-	Note that a side effect of this function is that the ID generator
-	associated with the TimeSlideTable class in glue.ligolw.lsctables
-	is synchronized with the result, so that the next ID it generates
-	will not conflict with the IDs listed in the dictionary returned by
-	this function.
-
-	Note also that this utility function should not be how applications
-	that perform multiple manipulations with an XML file obtain the
-	time slide table's contents since this function re-parses the file
-	from scratch.  Instead, from the glue.ligolw package use
-	table.get_table(...).as_dict().
-	"""
-	warnings.warn("pylal.ligolw_tisi.load_time_slides() is deprecated.  use glue.ligolw library directly to load document instead.", DeprecationWarning)
-	time_slide_table = lsctables.TimeSlideTable.get_table(ligolw_utils.load_filename(filename, verbose = verbose, gz = gz, contenthandler = contenthandler))
-	time_slide_table.sync_next_id()
-	return time_slide_table.as_dict()
-
-
 #
 # =============================================================================
 #
@@ -213,14 +151,10 @@ def SlidesIter(slides):
 
 	>>> slides = {"H1": [-1, 0, 1], "H2": [-1, 0, 1], "L1": [0]}
 	>>> list(SlidesIter(slides))
-	[{'H2': -1, 'H1': -1, 'L1': 0}, {'H2': 0, 'H1': -1, 'L1': 0},
-	{'H2': 1, 'H1': -1, 'L1': 0}, {'H2': -1, 'H1': 0, 'L1': 0}, {'H2':
-	0, 'H1': 0, 'L1': 0}, {'H2': 1, 'H1': 0, 'L1': 0}, {'H2': -1, 'H1':
-	1, 'L1': 0}, {'H2': 0, 'H1': 1, 'L1': 0}, {'H2': 1, 'H1': 1, 'L1':
-	0}]
+	[offsetvector({'H2': -1, 'H1': -1, 'L1': 0}), offsetvector({'H2': -1, 'H1': 0, 'L1': 0}), offsetvector({'H2': -1, 'H1': 1, 'L1': 0}), offsetvector({'H2': 0, 'H1': -1, 'L1': 0}), offsetvector({'H2': 0, 'H1': 0, 'L1': 0}), offsetvector({'H2': 0, 'H1': 1, 'L1': 0}), offsetvector({'H2': 1, 'H1': -1, 'L1': 0}), offsetvector({'H2': 1, 'H1': 0, 'L1': 0}), offsetvector({'H2': 1, 'H1': 1, 'L1': 0})]
 	"""
 	instruments = slides.keys()
-	for slide in iterutils.MultiIter(*slides.values()):
+	for slide in itertools.product(*slides.values()):
 		yield offsetvector.offsetvector(zip(instruments, slide))
 
 
@@ -236,10 +170,7 @@ def Inspiral_Num_Slides_Iter(count, offsets):
 	Example:
 
 	>>> list(Inspiral_Num_Slides_Iter(3, {"H1": 0.0, "H2": 5.0,"L1": 10.0}))
-	[{'H2': -15.0, 'H1': -0.0, 'L1': -30.0}, {'H2': -10.0, 'H1': -0.0,
-	'L1': -20.0}, {'H2': -5.0, 'H1': -0.0, 'L1': -10.0}, {'H2': 0.0,
-	'H1': 0.0, 'L1': 0.0}, {'H2': 5.0, 'H1': 0.0, 'L1': 10.0}, {'H2':
-	10.0, 'H1': 0.0, 'L1': 20.0}, {'H2': 15.0, 'H1': 0.0, 'L1': 30.0}]
+	[offsetvector({'H2': -15.0, 'H1': -0.0, 'L1': -30.0}), offsetvector({'H2': -10.0, 'H1': -0.0, 'L1': -20.0}), offsetvector({'H2': -5.0, 'H1': -0.0, 'L1': -10.0}), offsetvector({'H2': 0.0, 'H1': 0.0, 'L1': 0.0}), offsetvector({'H2': 5.0, 'H1': 0.0, 'L1': 10.0}), offsetvector({'H2': 10.0, 'H1': 0.0, 'L1': 20.0}), offsetvector({'H2': 15.0, 'H1': 0.0, 'L1': 30.0})]
 
 	The output time slides are all integer multiples of the input time
 	shift vector in the range [-count, +count], and are returned in
